==> visier_api_analytic_model-22222222.99201.1880.tar.gz: visier_api_analytic_model-22222222.99201.1880/test/test_servicing_v2_objectconfiguration_concept_delete_with_context_dto.py <==
# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1880
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_analytic_model.models
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_with_context_dto import ServicingV2ObjectconfigurationConceptDeleteWithContextDTO

class TestServicingV2ObjectconfigurationConceptDeleteWithContextDTO(unittest.TestCase):
    """ServicingV2ObjectconfigurationConceptDeleteWithContextDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicingV2ObjectconfigurationConceptDeleteWithContextDTO:
        """Test ServicingV2ObjectconfigurationConceptDeleteWithContextDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(
                execution_context = visier_api_analytic_model.models.servicing/v2/objectconfiguration/execution_context_dto.servicing.v2.objectconfiguration.ExecutionContextDTO(
                    tenant_code = '', 
                    project_id = '', ),
                concept = visier_api_analytic_model.models.servicing/v2/objectconfiguration/concept_delete_dto.servicing.v2.objectconfiguration.ConceptDeleteDTO(
                    uuid = '', 
                    object_name = '', )
            )
        else:
            return ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(
        )

    def testServicingV2ObjectconfigurationConceptDeleteWithContextDTO(self):
        """Test ServicingV2ObjectconfigurationConceptDeleteWithContextDTO"""
        def validate_instance(instance):
            ServicingV2ObjectconfigurationConceptDeleteWithContextDTO.model_validate(inst_req_only)
            instance_deserialized = ServicingV2ObjectconfigurationConceptDeleteWithContextDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()

==> visier_api_analytic_model-22222222.99201.1892.tar.gz: visier_api_analytic_model-22222222.99201.1892/test/test_servicing_v2_objectconfiguration_concept_delete_with_context_dto.py <==
# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1892
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_analytic_model.models
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_with_context_dto import ServicingV2ObjectconfigurationConceptDeleteWithContextDTO

class TestServicingV2ObjectconfigurationConceptDeleteWithContextDTO(unittest.TestCase):
    """ServicingV2ObjectconfigurationConceptDeleteWithContextDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicingV2ObjectconfigurationConceptDeleteWithContextDTO:
        """Test ServicingV2ObjectconfigurationConceptDeleteWithContextDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(
                execution_context = visier_api_analytic_model.models.servicing/v2/objectconfiguration/execution_context_dto.servicing.v2.objectconfiguration.ExecutionContextDTO(
                    tenant_code = '', 
                    project_id = '', ),
                concept = visier_api_analytic_model.models.servicing/v2/objectconfiguration/object_id_dto.servicing.v2.objectconfiguration.ObjectIdDTO(
                    uuid = '', 
                    object_name = '', )
            )
        else:
            return ServicingV2ObjectconfigurationConceptDeleteWithContextDTO(
        )

    def testServicingV2ObjectconfigurationConceptDeleteWithContextDTO(self):
        """Test ServicingV2ObjectconfigurationConceptDeleteWithContextDTO"""
        def validate_instance(instance):
            ServicingV2ObjectconfigurationConceptDeleteWithContextDTO.model_validate(inst_req_only)
            instance_deserialized = ServicingV2ObjectconfigurationConceptDeleteWithContextDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()
